@@ -10,7 +10,7 @@ def main():
     NAME
         squidm_magic.py
     DESCRIPTION
-        Converts SQUID microscopy files into a MagIC format files.
+        Converts SQUID microscopy files into MagIC format files.
         This program currently supports only specimens from a single sample.  
         Method codes are applied to all rows in each table. To add method codes
         to individual rows, edit the MagIC file after this program creates it.
@@ -24,9 +24,9 @@ def main():
         The top directory should contain directories named for each of the SQUID
         microscopy scan groups. This name will be used as the specimen name in
         the MagIC specimen table that is created by this program. In each scan
-        directory there should directories labeled "demag", "data", "images". The
-        data directory should contain the .bz and .inf files for each SQUID
-        microscopy scan. The .bz and .inf files must have the same name. The 
+        directory there should be directories labeled "demag", "data", "images". The
+        data directory should contain the .bz, .inf, and .fits files for each SQUID
+        microscopy scan. The .bz, .inf, and .fits files must have the same name. The 
         demag directory should have a .sam file that has the same name as the
         name of the directory 2 levels up. That is, if the main directory is ZirconRun2,
         then the .sam file should be named ZirconRun2.sam. There should also be
@@ -36,6 +36,10 @@ def main():
         image files that will be uploaded to MagIC along with the data. .jpg, .png,
         .gif, .pdf, etc. type files.
 
+        The .fits file format is: moment in emu, declination, inclination, height, residuals
+        An example of the text in a .fits file:
+        1.51e-10,54.36,220.92,0.000429,0.4214
+
         Example file directory tree:
         ZirconRun1 -- (file hierarchy) 
         ZirconRun2 -- data -- run2N_140C_100k.bz
@@ -109,9 +113,9 @@ def main():
                        (":" between multiple entries)
                        Required
 
-        -spec_method_codes: method_codes used for all specimens
+        -spec_method_codes: method_codes used for all specimens. Put LP-NOMAG method code last, if used.
                        (":" between multiple entries)
-                       Required
+                       Required 
 
         -meas_method_codes: method_codes used for all measurements
                        (":" between multiple entries)
@@ -132,7 +136,7 @@ def main():
 
         -model_doi: doi reference for the model used to calculate the model height, and residuals
 
-        -oe: flag to use cgs units for magnetic field strength(Oe) or magnetic moment(emu) 
+        -A: don't average replicant measurements 
 
         -multi_samples: flag used to indicate to not remove the MagIC files upon finishing. This leaves the
                        MagIC files to be concatenated by another program when there are multiple samples in
@@ -140,6 +144,15 @@ def main():
 
         -meas_num: set the starting measurement name number. default:1
 
+        -labfield: the field strength that the sample was magnetized for an in-field step 
+                   in  microTesla. default:0.0
+
+        -phi: Angle between the specimen x-y plane and the dc field direction. 
+              Positive toward the positive z direction. 
+
+        -theta: Angle of the dc field direction when projected into the x-y plane. 
+                Positive x-axis is 0 and increasing toward the positive y-axis. 
+
         -ncn NCON: specify naming convention for the CIT sample files.
 
       Sample naming convention (NCON): 
@@ -155,8 +168,7 @@ def main():
         NB: all others you will have to either customize your self or e-mail webmaster@earthref.org for help.
 
       Example command for the example data file. Data from Weiss et al., 2018 (doi:10.1130/G39938.1):
-     squidm_magic.py -location "Jack Hills" -location_type "Outcrop" -geologic_classes "Metamorphic" -lithologies "Metaconglomerate" -geologic_types "Single Crystal" -lat "-26" -lon 117 -age_low 0.8 -age_high 2.6 -age_unit Ga -citations "10.1130/G39938.1" -site "Erawandoo Hill" -loc_method_codes "GM-UPB" -site_method_codes "GM-UPB" -samp_method_codes "SC-SQUIDM" -spec_method_codes "SC-SQUIDM" -geologic_types "Single Crystal" -sample RSES-57 -ncn 5 -instrument_codes "MIT SQIUD microscope" -oe 
-    
+    squidm_magic.py -location "Jack Hills" -location_type "Outcrop" -geologic_classes "Metamorphic" -lithologies "Metaconglomerate" -geologic_types "Single Crystal" -lat "-26" -lon 117 -age_low 0.8 -age_high 2.6 -age_unit Ga -citations "10.1130/G39938.1" -site "Erawandoo Hill" -loc_method_codes "GM-UPB" -site_method_codes "GM-UPB" -samp_method_codes "SC-SQUIDM" -spec_method_codes "SC-SQUIDM" -geologic_types "Single Crystal" -sample RSES-57 -ncn 5 -instrument_codes "MIT SQUID microscope" -model_height_name "SQUID Microscopy Model Height Lima And Weiss 2016" -model_residuals_name "SQUID Microscopy Residuals Lima And Weiss 2016" -model_doi "10.1002/2016GC006487" -labfield 50.0 -phi 0.0 -theta 90 -A
     """
 
     if '-h' in sys.argv: # check if help is needed
@@ -336,6 +348,11 @@ def main():
     else:
         oe=''
 
+    if '-A' in sys.argv:
+        average='-A'
+    else:
+        average=''
+
     if '-multi_samples' in sys.argv:
         multi_samples=True
     else:
@@ -345,13 +362,34 @@ def main():
         ind=sys.argv.index('-meas_num')
         meas_num=int(sys.argv[ind+1])
     else:
-        if os.path.isfile('../last_measurement_number'):
-            f=open('../last_measurement_number','r')
-            meas_num=int(f.readline())
-            f.close()
+        if multi_samples:
+            if os.path.isfile('../last_measurement_number'):
+                f=open('../last_measurement_number','r')
+                meas_num=int(f.readline())
+                f.close()
+            else:
+                meas_num=1
         else:
             meas_num=1
 
+    if '-labfield' in sys.argv:
+        ind=sys.argv.index('-labfield')
+        labfield=sys.argv[ind+1]
+    else:
+        dc_field='0.0'
+
+    if '-phi' in sys.argv:
+        ind=sys.argv.index('-phi')
+        phi=sys.argv[ind+1]
+    else:
+        phi='0.0'
+
+    if '-theta' in sys.argv:
+        ind=sys.argv.index('-theta')
+        theta=sys.argv[ind+1]
+    else:
+        theta='0.0'
+
     if '-ncn' in sys.argv:
         ind=sys.argv.index('-ncn')
         ncn=sys.argv[ind+1]
@@ -372,7 +410,7 @@ def main():
     os.system("rm -r measurements")
 
     dir_list=os.listdir()
-#    print(sorted(dir_list))
+    print('dir_list=',sorted(dir_list))
     slide_dir_list=[]
     image_dir_list=[]
     specimen_list=[]
@@ -416,22 +454,38 @@ def main():
             continue
         specimen=dir
         slide_dir_list.append(dir+'/demag/')
-        image_dir_list.append(dir+'/images/')
         specimen_list.append(dir)
 #        print("specimen_list",specimen_list)
 
+        # create images.txt file when images directories are present
+        if os.path.isdir(dir+'/images/'): 
+            image_dir_list.append(dir+'/images/')
+            os.chdir(dir+'/images')
+            if os.path.isfile("images.txt"):
+                os.system("rm images.txt") 
+            image_file_names=os.listdir()
+            f_images=open('images.txt','w')
+            f_images.write('tab\timages\n')
+            f_images.write('specimen\tfile\ttype\ttitle\tkeywords\n')
+            for file_name in image_file_names:
+                title_split=file_name.split(".")
+                title=title_split[0]
+                f_images.write(dir+'\t'+file_name+'\tScanning SQUID Microscopy\t'+title+'\tScanning SQUID Microscopy\n')
+            f_images.close()
+        print("image_dir_list",image_dir_list)
+        os.chdir('../..')
+        
         # create MagIC files from cit files
         os.chdir(dir+'/demag')     
-        if spec_method_codes == "":
-            command='cit_magic.py -ncn ' + ncn + oe + '-f ' + dir + '.sam -loc "' + location + '" -sn "' + site + '" -sampname "' + sample + '"'
-        else:
-            command='cit_magic.py -ncn ' + ncn + oe + '-f ' + dir + '.sam -loc "' + location + '" -sn "' + site + '" -sampname "' + sample + '" -mcd ' + spec_method_codes
+        command='cit_magic.py -ncn ' + ncn + ' -f ' + dir + '.sam -loc "' + location + '" -sn "' + site + '" -sampname "' + sample + '" -dc ' + labfield + ' '  + phi + ' ' + theta + ' ' + average
+        if spec_method_codes != "":
+            command+=' -mcd ' + spec_method_codes
         print(command)
         os.system(command)
 
         # add info to specimens table
         df=pd.read_csv("specimens.txt",sep="\t",header=1)
-        df=append_column(df,"method_codes",spec_method_codes)
+        df=append_to_column(df,"method_codes",spec_method_codes)
         df=update_column(df,"citations",citations)
         df=update_column(df,"geologic_classes",geologic_classes)
         df=update_column(df,"lithologies",lithologies)
@@ -441,7 +495,7 @@ def main():
 
         # add info to measurements table
         df=pd.read_csv("measurements.txt",sep="\t",header=1)
-        df=append_column(df,"method_codes",meas_method_codes)
+        df=append_to_column(df,"method_codes",meas_method_codes)
         df=update_column(df,"citations",citations)
         df=update_column(df,"instrument_codes",instrument_codes)
         df.to_csv("measurements.txt",sep='\t',index=False)
@@ -461,11 +515,12 @@ def main():
 
 #   Combine the images tables and put the images in one folder
     image_files=""
+    print("XXXXXXXXXXXXXXXXXXXXXXXXXXX")
+    print("image dir list=",image_dir_list)
+    print("XXXXXXXXXXXXXXXXXXXXXXXXXXX")
     for dir in image_dir_list:
         image_files+=dir+ "images.txt "
     os.system("combine_magic.py -F images.txt -f " + image_files)
-
-    print("image dir list=",image_dir_list)
     os.mkdir("images")
     for dir in image_dir_list:
         os.system("cp " + dir + "* images")
@@ -707,10 +762,13 @@ def update_column(df,column,value):
     df[column] = column_values
     return(df)
         
-def append_column(df,column,value):
-    # add value to all of the values in column
+def append_to_column(df,column,value):
+    # add value to all of the values in column except when the value already is in the original value
     for index, row in df.iterrows():
-        df.loc[index,column]=value + ":" + df.loc[index,column]    
+        value_list = value.split(':')
+        for method_code in value_list:
+            if method_code not in df.loc[index,column]:
+                df.loc[index,column]= method_code + ":" + df.loc[index,column]
     return(df)
 
 def add_head(table):
